/* Blink Example

   This example code is in the Public Domain (or CC0 licensed, at your option.)

   Unless required by applicable law or agreed to in writing, this
   software is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
   CONDITIONS OF ANY KIND, either express or implied.
*/
#include <stdio.h>
#include "freertos/FreeRTOS.h"
#include "freertos/task.h"
#include "driver/gpio.h"
#include "sdkconfig.h"
#include "nvs_flash.h"
#include "esp_log.h"
#include "esp_partition.h"
#include <string.h>
#define DEBUG_MSGS  "APP_DEBUG"
/* Can run 'make menuconfig' to choose the GPIO to blink,
   or you can edit the following line and set a number here.
*/
#define BLINK_GPIO CONFIG_BLINK_GPIO

static nvs_handle nvsHandle;

void blink_task(void *pvParameter)
{
    /* Configure the IOMUX register for pad BLINK_GPIO (some pads are
       muxed to GPIO on reset already, but some default to other
       functions and need to be switched to GPIO. Consult the
       Technical Reference for a list of pads and their default
       functions.)
    */
    gpio_pad_select_gpio(BLINK_GPIO);
    /* Set the GPIO as a push/pull output */
    gpio_set_direction(BLINK_GPIO, GPIO_MODE_OUTPUT);
    while(1) {
        /* Blink off (output low) */
        gpio_set_level(BLINK_GPIO, 0);
        vTaskDelay(1000 / portTICK_PERIOD_MS);
        /* Blink on (output high) */
        gpio_set_level(BLINK_GPIO, 1);
        vTaskDelay(1000 / portTICK_PERIOD_MS);
    }
}

esp_err_t esphal_nvs_write(char *block, const void *data, uint16_t length)
{
    esp_err_t err = ESP_OK;
    err = nvs_set_blob(nvsHandle, block, data,length);
    if (err != ESP_OK) {
        ESP_LOGI(DEBUG_MSGS,"%s(%d) Error (0x%x) !", __func__,__LINE__,err);
        goto END;
    }
    err = nvs_commit(nvsHandle);
    if (err != ESP_OK) {
        ESP_LOGI(DEBUG_MSGS,"%s(%d) Error (0x%x) !",__func__,__LINE__,err);
        goto END;
    }
END:
    return err;
}

uint32_t nvsSize;
void app_main()
{
    esp_err_t err;
    err = nvs_flash_init();
    if (err != ESP_OK) {
        ESP_LOGI(DEBUG_MSGS,"%s(%d) Error (%d) in flash_init!",__FUNCTION__,__LINE__,err);
        return;
//        ESP_ERROR_CHECK(nvs_flash_erase());
//        err = nvs_flash_init();
    }
    ESP_ERROR_CHECK( err );
    err = nvs_open("storage", NVS_READWRITE, &nvsHandle);
    if (err != ESP_OK) 
        ESP_LOGI(DEBUG_MSGS,"%s(%d) Error (%d) opening NVS handle!",__FUNCTION__,__LINE__,err);

    const esp_partition_t* partition = esp_partition_find_first(
            ESP_PARTITION_TYPE_DATA, ESP_PARTITION_SUBTYPE_DATA_NVS, NVS_DEFAULT_PART_NAME);
    if (partition == NULL) {
        return;
    }
    nvsSize = partition->size;

{
    #define CHUNK_SIZE          1024
    uint8_t value = 0xAA;
    char *buff;
    uint8_t numberOfChunks;
    esp_err_t err = ESP_OK;
    bool retVal = true;
    buff = (char *) malloc(CHUNK_SIZE);
    ESP_LOGI(DEBUG_MSGS,"nvsSize = %d",nvsSize);
    numberOfChunks = nvsSize/CHUNK_SIZE;
    ESP_LOGI(DEBUG_MSGS,"numberOfChunks = %d",numberOfChunks);
    memset(buff,value,CHUNK_SIZE);
    for(uint8_t i =0;i<numberOfChunks;i++)
    {
        char tempBlkName[16]={0};
        char index[4]={0};
        sprintf(index,"%d",i);
        strcat(tempBlkName,"mfgBlk");
        strcat(tempBlkName,index);
        ESP_LOGI(DEBUG_MSGS,"(%d) tempBlkName = %s",i,tempBlkName);
        err = esphal_nvs_write(tempBlkName,buff,CHUNK_SIZE);
        if (err !=ESP_OK)
        {
            ESP_LOGE(DEBUG_MSGS,"%s(%d) Error = 0x%x at index: %d",__FUNCTION__,__LINE__,err,i);
        }
    }
    free(buff);
    return;
}

//    xTaskCreate(&blink_task, "blink_task", configMINIMAL_STACK_SIZE, NULL, 5, NULL);
}
